@@ -5,8 +5,12 @@ It can report coverage and, on supported architecutres, even reports memory acce
 
 /// The frida address sanitizer runtime
 pub mod asan_rt;
-/// The `LibAFL` firda helper
+/// The `LibAFL` frida helper
 pub mod helper;
+// for parsing asan cores
+use libafl::bolts::os::parse_core_bind_arg;
+// for getting current core_id
+use core_affinity::get_core_ids;
 
 /// A representation of the various Frida options
 #[derive(Clone, Debug)]
@@ -31,6 +35,7 @@ impl FridaOptions {
     #[must_use]
     pub fn parse_env_options() -> Self {
         let mut options = Self::default();
+        let mut asan_cores = None;
 
         if let Ok(env_options) = std::env::var("LIBAFL_FRIDA_OPTIONS") {
             for option in env_options.trim().split(':') {
@@ -40,7 +45,6 @@ impl FridaOptions {
                 match name {
                     "asan" => {
                         options.enable_asan = value.parse().unwrap();
-
                         #[cfg(not(target_arch = "aarch64"))]
                         if options.enable_asan {
                             panic!("ASAN is not currently supported on targets other than aarch64");
@@ -55,6 +59,9 @@ impl FridaOptions {
                     "asan-allocation-backtraces" => {
                         options.enable_asan_allocation_backtraces = value.parse().unwrap();
                     }
+                    "asan-cores" => {
+                        asan_cores = parse_core_bind_arg(value);
+                    }
                     "instrument-suppress-locations" => {
                         options.instrument_suppress_locations = Some(
                             value
@@ -92,6 +99,19 @@ impl FridaOptions {
                         panic!("unknown FRIDA option: '{}'", option);
                     }
                 }
+            } // end of for loop
+
+            if options.enable_asan {
+                if let Some(asan_cores) = asan_cores {
+                    let core_ids = get_core_ids().unwrap();
+                    assert_eq!(
+                        core_ids.len(),
+                        1,
+                        "Client should only be enabled on one core"
+                    );
+                    let core_id = core_ids[0].id;
+                    options.enable_asan = asan_cores.contains(&core_id);
+                }
             }
         }
 
